Description Usage Arguments Details Value See Also
A predicate function is one that takes a single argument returns either true or
false. position takes such a function, applies it to a functional list,
and returns the position of first object where the function returns TRUE.
1 |
ls |
A function, with class |
fn |
A predicate function, as described above |
start |
A index of the list to begin the search (remember, cardinal numbers) |
Remember, in this package we use cardinal numbers, counting from 0.
Either the first object that fulfills the predicate or FALSE.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.